Search Linux Wireless

[PATCH 03/13] staging: vt6656: clean up MACvDisableKeyEntry

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Remove internal white space and camel case.

Camel case changes;
pDevice -> priv
uEntryIdx -> entry_idx
byData -> data

Removed wOffset and dead code

Signed-off-by: Malcolm Priestley <tvboxspy@xxxxxxxxx>
---
 drivers/staging/vt6656/mac.c | 34 ++++++++++------------------------
 1 file changed, 10 insertions(+), 24 deletions(-)

diff --git a/drivers/staging/vt6656/mac.c b/drivers/staging/vt6656/mac.c
index 0f8132b8..13c15fa 100644
--- a/drivers/staging/vt6656/mac.c
+++ b/drivers/staging/vt6656/mac.c
@@ -98,40 +98,26 @@ void MACvSetBBType(struct vnt_private *priv, u8 type)
 
 /*
  * Description:
- *      Disable the Key Entry by MISCFIFO
+ *	Disable the Key Entry
  *
  * Parameters:
  *  In:
  *      dwIoBase        - Base Address for MAC
  *
- *  Out:
- *      none
+ * Out:
+ *	none
  *
  * Return Value: none
  *
  */
-void MACvDisableKeyEntry(struct vnt_private *pDevice, u32 uEntryIdx)
+void MACvDisableKeyEntry(struct vnt_private *priv, u32 entry_idx)
 {
-	u16 wOffset;
-	u8 byData;
-
-    byData = (u8) uEntryIdx;
+	u8 data;
 
-    wOffset = MISCFIFO_KEYETRY0;
-    wOffset += (uEntryIdx * MISCFIFO_KEYENTRYSIZE);
-
-    //VNSvOutPortW(dwIoBase + MAC_REG_MISCFFNDEX, wOffset);
-    //VNSvOutPortD(dwIoBase + MAC_REG_MISCFFDATA, 0);
-    //VNSvOutPortW(dwIoBase + MAC_REG_MISCFFCTL, MISCFFCTL_WRITE);
+	data = (u8)entry_idx;
 
-    //issue write misc fifo command to device
-    CONTROLnsRequestOut(pDevice,
-                        MESSAGE_TYPE_CLRKEYENTRY,
-                        0,
-                        0,
-                        1,
-                        &byData
-                        );
+	CONTROLnsRequestOut(priv, MESSAGE_TYPE_CLRKEYENTRY,
+		0, 0, sizeof(u8), &data);
 }
 
 /*
@@ -98,40 +98,26 @@ void MACvSetBBType(struct vnt_private *priv, u8 type)
  *
  * Parameters:
- *  In:
- *      dwIoBase        - Base Address for MAC
+ * In:
+ *	entry_idx - Base Address for MAC
  *
-- 
1.8.1.2



--
To unsubscribe from this list: send the line "unsubscribe linux-wireless" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html




[Index of Archives]     [Linux Host AP]     [ATH6KL]     [Linux Wireless Personal Area Network]     [Linux Bluetooth]     [Linux Netdev]     [Kernel Newbies]     [Linux Kernel]     [IDE]     [Git]     [Netfilter]     [Bugtraq]     [Yosemite Hiking]     [MIPS Linux]     [ARM Linux]     [Linux RAID]

  Powered by Linux